#!/bin/bash -eux

echo "Creating the bucket if necessary."
aws s3api --endpoint=${AWS_ENDPOINT} create-bucket --bucket ${OBJECTSTORE_S3_BUCKET}

echo "Testing the s3 bucket."
aws --endpoint=${AWS_ENDPOINT} s3 ls s3://${OBJECTSTORE_S3_BUCKET}

mkdir -p /s3/data/
mkdir -p /s3/config/

echo "Creating the user file list."
mysql --host=${MYSQL_HOST} -p${MYSQL_ROOT_PASSWORD} -B --disable-column-names -D ${MYSQL_DATABASE} --default-character-set=utf8mb4 << EOF > /s3/config/user_file_list
   select concat('urn:oid:', fileid, ' ', '${NEXTCLOUD_DATA_PATH}', substring(id from 7), '/', path)
     from ${NEXTCLOUD_TABLE_PREFIX}filecache
     join ${NEXTCLOUD_TABLE_PREFIX}storages
      on storage = numeric_id
   where id like 'home::%'
   order by id;
EOF

echo "Creating the user file list."
mysql --host=${MYSQL_HOST} -p${MYSQL_ROOT_PASSWORD} -B --disable-column-names -D ${MYSQL_DATABASE} --default-character-set=utf8mb4 << EOF > /s3/config/meta_file_list
   select concat('urn:oid:', fileid, ' ', substring(id from 8), path)
     from ${NEXTCLOUD_TABLE_PREFIX}filecache
     join ${NEXTCLOUD_TABLE_PREFIX}storages
       on storage = numeric_id
     where id like 'local::%'
     order by id;
EOF

cd /s3/data

while read target source ; do
    if [ -f "$source" ] ; then
        ln -s "$source" "$target"
    fi
done < /s3/config/user_file_list

while read target source ; do
    if [ -f "$source" ] ; then
        ln -s "$source" "$target"
    fi
done < /s3/config/meta_file_list

aws --endpoint=${AWS_ENDPOINT} s3 sync . s3://${OBJECTSTORE_S3_BUCKET}
